@@ -18,7 +18,7 @@ def fromstring(context, parser=None, custom_parser=None):
                 return [etree.fromstring(context)]
             except etree.XMLSyntaxError:
                 return [lxml.html.fromstring(context)]
-        
+
         elif parser == 'xml':
             custom_parser = etree.fromstring
         elif parser == 'html':
@@ -30,7 +30,7 @@ def fromstring(context, parser=None, custom_parser=None):
             custom_parser = lxml.html.fragments_fromstring
         else:
             ValueError('No such parser: "%s"' % parser)
-    
+
     result = custom_parser(context)
     if type(result) is list:
         return result
@@ -39,7 +39,7 @@ def fromstring(context, parser=None, custom_parser=None):
 
 def callback(func, *args):
     return func(*args[:func.func_code.co_argcount])
-        
+
 class NoDefault(object):
     def __repr__(self):
         """clean representation in Sphinx"""
@@ -114,7 +114,7 @@ class PyQuery(list):
                     data = kwargs.get('data')
                     if type(data) in (dict, list, tuple):
                         data = urlencode(data)
-                        
+
                     if isinstance(method, basestring) and method.lower() == 'get' and data:
                         if '?' not in url:
                             url += '?'
@@ -122,7 +122,7 @@ class PyQuery(list):
                             url += '&'
                         url += data
                         data = None
-                    
+
                     html = urlopen(url, data).read()
                 self._base_url = url
             else:
@@ -397,17 +397,21 @@ class PyQuery(list):
         return self.__class__([e for e in self if e not in exclude], **dict(parent=self))
 
     def is_(self, selector):
-        """Returns True if selector matches at least one current element, else False.
+        """Returns True if selector matches at least one current element, else False::
+
             >>> d = PyQuery('<p class="hello">Hi</p><p>Bye</p><div></div>')
             >>> d('p').eq(0).is_('.hello')
             True
+
             >>> d('p').eq(1).is_('.hello')
             False
+
+        ..
         """
         return bool(self.__class__(selector, self))
 
     def find(self, selector):
-        """Find elements using selector traversing down from self.
+        """Find elements using selector traversing down from self::
 
             >>> m = '<p><span><em>Whoah!</em></span></p><p><em> there</em></p>'
             >>> d = PyQuery(m)
@@ -415,6 +419,8 @@ class PyQuery(list):
             [<em>, <em>]
             >>> d('p').eq(1).find('em')
             [<em>]
+
+        ..
         """
         xpath = selector_to_xpath(selector)
         results = [child.xpath(xpath) for tag in self for child in tag.getchildren()]
@@ -425,7 +431,7 @@ class PyQuery(list):
         return self.__class__(elements, **dict(parent=self))
 
     def eq(self, index):
-        """Return PyQuery of only the element with the provided index.
+        """Return PyQuery of only the element with the provided index::
 
             >>> d = PyQuery('<p class="hello">Hi</p><p>Bye</p><div></div>')
             >>> d('p').eq(0)
@@ -434,6 +440,8 @@ class PyQuery(list):
             [<p>]
             >>> d('p').eq(2)
             []
+
+        ..
         """
         # Use slicing to silently handle out of bounds indexes
         items = self[index:index+1]
@@ -456,7 +464,7 @@ class PyQuery(list):
         """Returns a new PyQuery after transforming current items with func.
 
         func should take two arguments - 'index' and 'element'.  Elements can
-        also be referred to as 'this' inside of func.
+        also be referred to as 'this' inside of func::
 
             >>> d = PyQuery('<p class="hello">Hi there</p><p>Bye</p><br />')
             >>> d('p').map(lambda i, e: PyQuery(e).text())
@@ -467,9 +475,6 @@ class PyQuery(list):
 
             >>> d('p').map(lambda i, e: PyQuery(this).text().split())
             ['Hi', 'there', 'Bye']
-            
-            Added this 
-
 
         """
         items = []
@@ -550,6 +555,7 @@ class PyQuery(list):
             >>> d.removeAttr('id')
             [<div>]
 
+        ..
         """
         for tag in self:
             del tag.attrib[name]
@@ -577,6 +583,7 @@ class PyQuery(list):
             >>> d.hasClass('myclass')
             True
 
+        ..
         """
         return self.is_('.%s' % name)
 
@@ -587,6 +594,7 @@ class PyQuery(list):
             >>> d.addClass('myclass')
             [<div.myclass>]
 
+        ..
         """
         for tag in self:
             values = value.split(' ')
@@ -597,12 +605,13 @@ class PyQuery(list):
         return self
 
     def removeClass(self, value):
-        """Remove a css class to elements
+        """Remove a css class to elements::
 
             >>> d = PyQuery('<div class="myclass"></div>')
             >>> d.removeClass('myclass')
             [<div>]
 
+        ..
         """
         for tag in self:
             values = value.split(' ')
@@ -674,12 +683,20 @@ class PyQuery(list):
     # CORE UI EFFECTS #
     ###################
     def hide(self):
-        """add display:none to elements style
+        """remove display:none to elements style
+
+            >>> print PyQuery('<div style="display:none;"/>').hide()
+            <div style="display: none"/>
+
         """
         return self.css('display', 'none')
 
     def show(self):
         """add display:block to elements style
+
+            >>> print PyQuery('<div />').show()
+            <div style="display: block"/>
+
         """
         return self.css('display', 'block')
 
@@ -687,11 +704,14 @@ class PyQuery(list):
     # HTML #
     ########
     def val(self, value=no_default):
-        """Set/get the attribute value::
+        """Set the attribute value::
 
             >>> d = PyQuery('<input />')
             >>> d.val('Youhou')
             [<input>]
+
+        Get the attribute value::
+
             >>> d.val()
             'Youhou'
 
@@ -742,7 +762,7 @@ class PyQuery(list):
         return self
 
     def outerHtml(self):
-        """Get the html representation of the first selected element.
+        """Get the html representation of the first selected element::
 
             >>> d = PyQuery('<div><span class="red">toto</span> rocks</div>')
             >>> print d('span')
@@ -753,8 +773,10 @@ class PyQuery(list):
             >>> S = PyQuery('<p>Only <b>me</b> & myself</p>')
             >>> S('b').outerHtml()
             '<b>me</b>'
+
+        ..
         """
-        
+
         if not self:
             return None
         e0 = self[0]
@@ -762,7 +784,7 @@ class PyQuery(list):
             e0 = deepcopy(e0)
             e0.tail = ''
         return lxml.html.tostring(e0)
-        
+
     def text(self, value=no_default):
         """Get or set the text representation of sub nodes.
 
@@ -968,6 +990,7 @@ class PyQuery(list):
             >>> print d('span').wrapAll('<div id="wrapper"></div>')
             <div id="wrapper"><span>Hey</span><span>you !</span></div>
 
+        ..
         """
         if not self:
             return self
@@ -1043,7 +1066,7 @@ class PyQuery(list):
 
     def remove(self, expr=no_default):
         """remove nodes
-        
+
         >>> d = PyQuery('<div>Maybe <em>she</em> does <strong>NOT</strong> know</div>')
         >>> d('strong').remove()
         [<strong>]
@@ -1071,13 +1094,13 @@ class PyQuery(list):
         return self
 
     class Fn(object):
-        """Hook for defining custom funcion (like the jQuery.fn)
-        
+        """Hook for defining custom function (like the jQuery.fn)
+
         >>> PyQuery.fn.listOuterHtml = lambda: this.map(lambda i, el: PyQuery(this).outerHtml())
         >>> S = PyQuery('<ol>   <li>Coffee</li>   <li>Tea</li>   <li>Milk</li>   </ol>')
         >>> S('li').listOuterHtml()
         ['<li>Coffee</li>', '<li>Tea</li>', '<li>Milk</li>']
-        
+
         """
         def __setattr__(self, name, func):
             def fn(self, *args):
@@ -1086,7 +1109,7 @@ class PyQuery(list):
             fn.__name__ = name
             setattr(PyQuery, name, fn)
     fn = Fn()
-    
+
     #####################################################
     # Additional methods that are not in the jQuery API #
     #####################################################
